@@ -38,6 +38,17 @@ class TestConfig(TestBase):
     def test_default_settings(self):
         self.assertEqual(self.app.settings, self.settings_file)
 
+        # TODO add tests for other global default values
+        self.assertEqual(self.app.config['RATE_LIMIT_GET'], None)
+        self.assertEqual(self.app.config['RATE_LIMIT_POST'], None)
+        self.assertEqual(self.app.config['RATE_LIMIT_PATCH'], None)
+        self.assertEqual(self.app.config['RATE_LIMIT_DELETE'], None)
+
+        self.assertEqual(self.app.config['MONGO_HOST'], 'localhost')
+        self.assertEqual(self.app.config['MONGO_PORT'], 27017)
+        self.assertEqual(self.app.config['MONGO_QUERY_BLACKLIST'], ['$where',
+                                                                    '$regex'])
+
     def test_unexisting_pyfile_config(self):
         self.assertRaises(IOError, Eve, settings='an_unexisting_pyfile.py')
 
@@ -167,6 +178,8 @@ class TestConfig(TestBase):
                          self.app.config['AUTH_USERNAME_FIELD'])
         self.assertEqual(settings['allow_unknown'],
                          self.app.config['ALLOW_UNKNOWN'])
+        self.assertEqual(settings['extra_response_fields'],
+                         self.app.config['EXTRA_RESPONSE_FIELDS'])
 
         self.assertNotEqual(settings['schema'], None)
         self.assertEqual(type(settings['schema']), dict)
