@@ -6,11 +6,21 @@ from eve.auth import BasicAuth, TokenAuth, HMACAuth
 from hashlib import sha1
 import hmac
 from flask import request
+from redis import Redis
 
+redis = Redis()
+
+
+class TAuth(TokenAuth):
+    def check_auth(self, token, allowed_roles, resource):
+        print token, resource
+        return token == 'token'
 
 class Auth(BasicAuth):
-    def check_auth(self, username, password, allowed_roles):
-        return username == 'admin' and password == 'secret'
+    def check_auth(self, username, password, allowed_roles, resource):
+        print "resource:",resource
+        return username == 'token'
+        #return username == 'admin' and password == 'secret'
 
 
 class Validator(Validator):
@@ -31,14 +41,25 @@ def resource_gotit(request, response):
 
 def resource_post(request, response):
     print 'post_contacts'
-    print request
+    print request.authorization
+    print request.form
     print response
 
-app = Eve(validator=Validator)
+def posting(resource, documents):
+    print "posting to ", resource
+    documents[0]["token"] = "mytoken"
+
+def posting_r(documents):
+    print "posting to resource contacts"
+
+
+app = Eve(validator=Validator, auth=TAuth, redis=redis)
 #app.config['DOMAIN']['contacts']['auth_username_field'] = 'name'
 #app.on_get_contacts += resource_gotit
 #app.on_get += gotit
 #app.on_post_contacts += resource_post
+#app.on_posting += posting
+app.on_posting_contacts += posting_r
 
 if __name__ == '__main__':
     #app.events.on_getting += pre
